Module source

Module source 

Source registration helpers for Joule Profiler.

Structs

MetricSourceConfig
Metric source configuration wrapper.

Functions

register_source
Builds a metric source reader of type R from config_table and, if successful, attaches it to profiler.
register_source_override
Builds a metric source reader with an external config override, then attaches it to profiler if initialization succeeds.