register_source

Function register_source 

pub fn register_source<R>(
    profiler: &mut JouleProfiler,
    config_table: &mut ConfigTable,
) -> Result<()>
where R: MetricReader,
Builds a metric source reader of type R from config_table and, if successful, attaches it to profiler.

If the source is disabled or its initialization fails with ignore_on_failure set, no source is added and Ok(()) is returned silently.

Returns an error if source initialization fails and ignore_on_failure is not set in the source’s config.